'use strict';

var lib = require('web-blob');
var lib$1 = require('../src/lib.cjs');
var test = require('./test.cjs');

test.test("test baisc", async (test) => {
  test.isEqual(typeof lib.Blob, "function");
  test.isEqual(typeof lib$1.File, "function");
});

test.test("new File", async (test) => {
  // @ts-expect-error
  test.throws(() => new lib$1.File(), TypeError);
  // @ts-expect-error
  test.throws(() => new lib$1.File([]), TypeError);

  const before = Date.now();
  await new Promise((resolve) => setTimeout(resolve, 3));
  const file = new lib$1.File(["test"], "name");
  await new Promise((resolve) => setTimeout(resolve, 3));
  const after = Date.now();
  test.equal(file.size, 4);
  test.equal(file.name, "name");
  test.equal(typeof file.lastModified, "number");
  test.ok(file.lastModified > before);
  test.ok(file.lastModified < after);
  test.equal(file.type, "");

  const chunks = [];
  // @ts-ignore - https://github.com/microsoft/TypeScript/issues/29867
  for await (const chunk of file.stream()) {
    chunks.push(chunk);
  }

  test.deepEqual(chunks, [new TextEncoder().encode("test")]);
});

test.test("File with lastModified", async (test) => {
  const file = new lib$1.File(["test"], "name", { lastModified: 1594672000418 });

  test.equal(file.size, 4);
  test.equal(file.name, "name");
  test.equal(file.lastModified, 1594672000418);
  test.equal(file.type, "");
});

test.test("File with type", async (test) => {
  const file = new lib$1.File(["test"], "name", {
    lastModified: 1594672000418,
    type: "text/plain",
  });

  test.equal(file.size, 4);
  test.equal(file.name, "name");
  test.equal(file.lastModified, 1594672000418);
  test.equal(file.type, "text/plain");
});

test.test("File type is normalized", async (test) => {
  const file = new lib$1.File(["test"], "name", {
    type: "Text/Plain",
  });

  test.equal(file.size, 4);
  test.equal(file.name, "name");
  test.equal(file.type, "text/plain");
});

test.test("File name is escaped", async (test) => {
  const file = new lib$1.File(["test"], "dir/name");

  test.equal(file.size, 4);
  test.equal(file.name, "dir:name");
  test.equal(file.type, "");
});
//# sourceMappingURL=file.spec.cjs.map
